@@ -23,13 +23,20 @@
 #include <runtime_spec_schema_config_schema.h>
 #include "error.h"
 
+enum handler_configure_phase
+{
+  HANDLER_CONFIGURE_BEFORE_MOUNTS = 1,
+  HANDLER_CONFIGURE_AFTER_MOUNTS,
+  HANDLER_CONFIGURE_MOUNTS,
+};
+
+struct custom_handler_manager_s;
+
 struct libcrun_context_s
 {
   const char *state_root;
   const char *id;
   const char *bundle;
-  const char *config_file;
-  const char *config_file_content;
   const char *console_socket;
   const char *pid_file;
   const char *notify_socket;
@@ -51,8 +58,7 @@ struct libcrun_context_s
   bool force_no_cgroup;
   bool no_pivot;
 
-  int (*exec_func) (void *container, void *arg, const char *pathname, char *const argv[]);
-  void *exec_func_arg;
+  struct custom_handler_manager_s *handler_manager;
 };
 
 enum
@@ -71,7 +77,8 @@ struct libcrun_container_s
   uid_t container_uid;
   gid_t container_gid;
 
-  bool use_intermediate_userns;
+  char *config_file;
+  char *config_file_content;
 
   void *private_data;
   void (*cleanup_private_data) (void *private_data);
@@ -84,6 +91,8 @@ typedef struct libcrun_container_status_s libcrun_container_status_t;
 typedef struct libcrun_container_s libcrun_container_t;
 typedef struct libcrun_context_s libcrun_context_t;
 
+struct container_entrypoint_s;
+
 struct libcrun_checkpoint_restore_s
 {
   char *image_path;
@@ -95,6 +104,9 @@ struct libcrun_checkpoint_restore_s
   bool detach;
   bool file_locks;
   const char *console_socket;
+  char *parent_path;
+  bool pre_dump;
+  int manage_cgroups_mode;
 };
 typedef struct libcrun_checkpoint_restore_s libcrun_checkpoint_restore_t;
 
@@ -110,11 +122,11 @@ LIBCRUN_PUBLIC int libcrun_container_run (libcrun_context_t *context, libcrun_co
 LIBCRUN_PUBLIC int libcrun_container_delete (libcrun_context_t *context, runtime_spec_schema_config_schema *def,
                                              const char *id, bool force, libcrun_error_t *err);
 
-LIBCRUN_PUBLIC int libcrun_container_kill (libcrun_context_t *context, const char *id, int signal,
+LIBCRUN_PUBLIC int libcrun_container_kill (libcrun_context_t *context, const char *id, const char *signal,
                                            libcrun_error_t *err);
 
-LIBCRUN_PUBLIC int libcrun_container_kill_all (libcrun_context_t *context, const char *id, int signal,
-                                               libcrun_error_t *err);
+LIBCRUN_PUBLIC int libcrun_container_killall (libcrun_context_t *context, const char *id, const char *signal,
+                                              libcrun_error_t *err);
 
 LIBCRUN_PUBLIC int libcrun_container_create (libcrun_context_t *context, libcrun_container_t *container,
                                              unsigned int options, libcrun_error_t *err);
@@ -124,6 +136,11 @@ LIBCRUN_PUBLIC int libcrun_container_start (libcrun_context_t *context, const ch
 LIBCRUN_PUBLIC int libcrun_container_state (libcrun_context_t *context, const char *id, FILE *out,
                                             libcrun_error_t *err);
 
+int libcrun_container_notify_handler (struct container_entrypoint_s *args,
+                                      enum handler_configure_phase phase,
+                                      libcrun_container_t *container, const char *rootfs,
+                                      libcrun_error_t *err);
+
 LIBCRUN_PUBLIC int libcrun_get_container_state_string (const char *id, libcrun_container_status_t *status,
                                                        const char *state_root, const char **container_status,
                                                        int *running, libcrun_error_t *err);
@@ -164,6 +181,8 @@ LIBCRUN_PUBLIC int libcrun_container_checkpoint (libcrun_context_t *context, con
 LIBCRUN_PUBLIC int libcrun_container_restore (libcrun_context_t *context, const char *id,
                                               libcrun_checkpoint_restore_t *cr_options, libcrun_error_t *err);
 
+LIBCRUN_PUBLIC int libcrun_container_read_pids (libcrun_context_t *context, const char *id, bool recurse, pid_t **pids, libcrun_error_t *err);
+
 // Not part of the public API, just a method in container.c we need to access from linux.c
 void get_root_in_the_userns (runtime_spec_schema_config_schema *def, uid_t host_uid, gid_t host_gid,
                              uid_t *uid, gid_t *gid);
